from setuptools import setup, find_packages

setup(
    name='gyatModel1',
    version='0.1.2',
    packages=find_packages(),
    include_package_data=True,
    package_data={
        'gyat_module': ['model1.txt', 'model2.txt', 'model3.txt'],
    },
    author='Micheal Scofield',
    description='A sample package that prints text file content',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    classifiers=[
        'Programming Language :: Python :: 3',
    ],
)
